@@ -51,6 +51,9 @@ class PolyInfo(BaseModel):
 class PolygonSchema(BaseModel):
     __root__: List[PolyInfo]
 
+class FrameLabelSchema(BaseModel):
+    category: str
+    attributes: Optional[AtrributeSchema] = AtrributeSchema().dict()
 
 class CategorySchema(BaseModel):
     category: str
@@ -63,6 +66,10 @@ class CategorySchema(BaseModel):
     uuid: str = Field(default_factory=gen_uuid)
     objectId: Optional[ObjectIdSchema]
 
+    def dict(self, *args, **kwargs) -> Dict:
+        kwargs.pop("exclude_none")
+        return super().dict(*args, exclude_none=True, **kwargs)
+
 
 class FrameSchema(BaseModel):
     name: str
@@ -70,13 +77,14 @@ class FrameSchema(BaseModel):
     dataset: str
     sequence: str
     labels: List[CategorySchema]
+    frameLabels: Optional[List[FrameLabelSchema]] = None
     meta_ds: Optional[MetaDsSchema] = None
 
 
 class BDDSchema(BaseModel):
     bdd_version: str = BDD_VERSION
-    company_code: Optional[str]
-    inference_object: Optional[str] = "detection"
-    meta_ds: Optional[Dict] = {}
-    meta_se: Optional[Dict] = {}
+    company_code: Optional[str] = None
+    inference_object: str = "detection"
+    meta_ds: Dict = {}
+    meta_se: Dict = {}
     frame_list: List[FrameSchema]
